package com.fs.qw.service;

import com.fs.qw.domain.QwMaterial;
import com.fs.qw.domain.QwMaterialGroup;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

public interface IQwMaterialGroupService {
    /**
     * 查询企微素材分组
     *
     * @param groupId 企微素材分组ID
     * @return 企微素材分组
     */
    public QwMaterialGroup selectQwMaterialGroupById(Long groupId);

    /**
     * 查询企微素材分组列表
     *
     * @param qwMaterialGroup 企微素材分组
     * @return 企微素材分组集合
     */
    public List<QwMaterialGroup> selectQwMaterialGroupList(QwMaterialGroup qwMaterialGroup);

    /**
     * 新增企微素材分组
     *
     * @param qwMaterialGroup 企微素材分组
     * @return 结果
     */
    public int insertQwMaterialGroup(QwMaterialGroup qwMaterialGroup);

    /**
     * 修改企微素材分组
     *
     * @param qwMaterialGroup 企微素材分组
     * @return 结果
     */
    public int updateQwMaterialGroup(QwMaterialGroup qwMaterialGroup);

    /**
     * 批量删除企微素材分组
     *
     * @param groupIds 需要删除的企微素材分组ID
     * @return 结果
     */
    public int deleteQwMaterialGroupByIds(Long[] groupIds);

    /**
     * 删除企微素材分组信息
     *
     * @param groupId 企微素材分组ID
     * @return 结果
     */
    public int deleteQwMaterialGroupById(Long groupId);
}
